<?php

add_action( 'admin_menu', 'register_vimeo_sync_page' );
add_action( 'admin_init', 'register_vimeo_sync_settings' );

if( !function_exists('register_vimeo_sync_settings')) {
    function register_vimeo_sync_settings() {
        register_setting( 'vimeo-sync-api', 'rvs_user_api_key' );
        register_setting( 'vimeo-sync-api', 'rvs_user_vimeo_account' );
        register_setting( 'wpvs-rest-api-keys', 'wpvs_rest_api_client_id' );
        register_setting( 'wpvs-rest-api-keys', 'wpvs_rest_api_secret' );

        register_setting( 'wpvs-video-settings', 'rvs_video_position' );
        register_setting( 'wpvs-video-settings', 'rvs_video_ordering' );
        register_setting( 'wpvs-video-settings', 'rvs_video_order_direction' );
        register_setting( 'wpvs-video-settings', 'rvs_video_autoplay' );
        register_setting( 'wpvs-video-settings', 'wpvs_autoplay_timer' );
        register_setting( 'wpvs-video-settings', 'rvs_vimeo_styling' );
        register_setting( 'wpvs-video-settings', 'rvs_load_template_css' );

        register_setting( 'wpvs-video-settings', 'wpvs-video-slug-settings' );
        register_setting( 'wpvs-video-settings', 'wpvs-genre-slug-settings' );
        register_setting( 'wpvs-video-settings', 'wpvs-actor-slug-settings' );
        register_setting( 'wpvs-video-settings', 'wpvs-director-slug-settings' );

        register_setting( 'vimeo-sync-access', 'rvs-username-access' );
        register_setting( 'vimeo-sync-access', 'wpvs-access-check-token' );
        register_setting( 'vimeo-sync-access', 'rvs-activated' );
        register_setting( 'vimeo-sync-access', 'rvs-access-check-time' );
        register_setting( 'vimeo-sync-settings', 'rvs_vimeo_video_settings' );
        register_setting( 'vimeo-sync-youtube', 'rvs_youtube_player_settings' );
        register_setting( 'wpvs-custom-player-settings', 'wpvs-custom-player' );
        global $wpvs_vimeo_config;
        $wpvs_vimeo_config = wpvs_create_vimeo_config();
    }
}


if( !function_exists('register_vimeo_sync_page')) {
    function register_vimeo_sync_page() {
        add_menu_page( 'WP Videos', 'WP Videos', 'manage_options', 'vimeo-sync', 'wpvs_api_key_setup',
    'dashicons-video-alt3');
        if( ! get_option('is-wp-videos-multi-site')) {
            add_submenu_page( 'vimeo-sync', 'Activation', 'Activation', 'manage_options', 'rvs-activation', 'rvs_activation' );
        }
        add_submenu_page( 'vimeo-sync', 'API Keys', 'API Keys', 'manage_options', 'vimeo-sync');
        add_submenu_page( 'vimeo-sync', 'Video Settings', 'Video Settings', 'manage_options', 'wpvs-video-settings', 'wpvs_video_settings');
        add_submenu_page( 'vimeo-sync', 'Import Videos', 'Import Videos', 'manage_options', 'rvs-video-sync', 'rvs_sync_videos' );
        add_submenu_page( 'vimeo-sync', 'Player Design', 'Player Design', 'manage_options', 'rvs-video-design', 'rvs_player_design' );
        add_submenu_page( 'vimeo-sync', 'Custom Player', 'Custom Player', 'manage_options', 'wpvs-custom-player-settings', 'wpvs_custom_player_settings');
        if( ! wpvs_check_for_membership_add_on()) {
            add_submenu_page( 'vimeo-sync', 'Subscriptions', 'Subscriptions', 'manage_options', 'rvs-membership-add-on', 'rvs_membership_add_on' );
        } else {
            do_action( 'rvs_add_membership_menu_items' );
        }
        remove_submenu_page('vimeo-sync','vimeo-sync');
    }
}


if( !function_exists('rvs_player_design')) {
    function rvs_player_design() {
        global $wpv_vimeosync_current_version;
        wp_enqueue_style( 'vimeo-sync-responsive', RVS_BASE_URL . 'css/responsive-video.css');
        wp_enqueue_style( 'wp-color-picker' );
        wp_enqueue_script('wp-color-picker' );
        wp_enqueue_script( 'vimeo-sync-video-settings', RVS_BASE_URL . 'js/rvs-video-settings.js',array(
                'jquery'), $wpv_vimeosync_current_version);
        require_once('rvs-video-design.php');
    }
}
if( !function_exists('rvs_sync_videos')) {
    function rvs_sync_videos() {
        wp_enqueue_script( 'vimeo-import', plugins_url( '../../js/vimeo/vimeo-import.js', __FILE__ ));
        wp_localize_script('vimeo-import', 'wpvsdata', array(
                'url' => RVS_BASE_URL .'image/missing-image.png'
            )
        );
        require_once('rvs-video-sync.php');
    }
}
if( !function_exists('rvs_membership_add_on')) {
    function rvs_membership_add_on() {
        require_once('rvs-membership-add-on.php');
    }
}

if( !function_exists('wpvs_video_settings')) {
    function wpvs_video_settings() {
        wp_enqueue_style( 'wp-color-picker' );
        wp_enqueue_script('wp-color-picker' );
        require_once('wp-videos-setup.php');
    }
}

if( !function_exists('wpvs_custom_player_settings')) {
    function wpvs_custom_player_settings() {
        $js_editor = wp_enqueue_code_editor( array( 'type' => 'text/javascript') );
        $css_editor = wp_enqueue_code_editor( array( 'type' => 'text/css') );
        $js_file_editor = wp_enqueue_code_editor( array( 'type' => 'text/html') );
        $css_file_editor = wp_enqueue_code_editor( array( 'type' => 'text/html') );
        wp_add_inline_script('code-editor',
        sprintf(
                'jQuery( function() { wp.codeEditor.initialize( "wpvs-js-editor", %s ); } );',
                wp_json_encode( $js_editor )
            )
        );
        wp_add_inline_script('code-editor',
        sprintf(
                'jQuery( function() { wp.codeEditor.initialize( "wpvs-css-editor", %s ); } );',
                wp_json_encode( $css_editor )
            )
        );
        wp_add_inline_script('code-editor',
        sprintf(
                'jQuery( function() { wp.codeEditor.initialize( "wpvs-js-file-editor", %s ); } );',
                wp_json_encode( $js_file_editor )
            )
        );
        wp_add_inline_script('code-editor',
        sprintf(
                'jQuery( function() { wp.codeEditor.initialize( "wpvs-css-file-editor", %s ); } );',
                wp_json_encode( $css_file_editor )
            )
        );
        require_once('wp-videos-custom-player-settings.php');
    }
}



if( !function_exists('wpvs_api_key_setup')) {
    function wpvs_api_key_setup() {
        wp_enqueue_script('wpvs-rest-api-setup' );
        require_once('wp-videos-vimeo-setup.php');
    }
}

if( !function_exists('rvs_activation')) {
    function rvs_activation() {
        require_once('rvs-activation.php');
    }
}

if( ! function_exists('wpvs_slug_changes_check') ) {
    function wpvs_slug_changes_check($old_value, $new_value) {
        if($old_value['slug'] != $new_value['slug']) {
            wp_schedule_single_event(time(), 'wpvs_run_flush_rewrite_event');
        }
    }
    add_action('update_option_wpvs-video-slug-settings', 'wpvs_slug_changes_check', 10, 2);
    add_action('update_option_wpvs-genre-slug-settings', 'wpvs_slug_changes_check', 10, 2);
    add_action('update_option_wpvs-actor-slug-settings', 'wpvs_slug_changes_check', 10, 2);
    add_action('update_option_wpvs-director-slug-settings', 'wpvs_slug_changes_check', 10, 2);
}

if( ! function_exists('wpvs_flush_rewrite_on_slug_changes') ) {
    function wpvs_flush_rewrite_on_slug_changes() {
        flush_rewrite_rules();
    }
    add_action( 'wpvs_run_flush_rewrite_event', 'wpvs_flush_rewrite_on_slug_changes' );
}
