<?php
if( ! class_exists('Vimeo\Vimeo') ) {
    include(RVS_BASE_DIR.'/vimeo/src/Vimeo/Vimeo.php');
}
use Vimeo\Vimeo;

add_action( 'wp_ajax_wp_videos_get_vimeo_page_ajax_request', 'wp_videos_get_vimeo_page_ajax_request' );

function wp_videos_get_vimeo_page_ajax_request() {
    global $wpvs_vimeo_api_key;
    if( ! empty($wpvs_vimeo_api_key) && get_option('rvs_key_authenticated') ) {
        $lib = new Vimeo($wpvs_vimeo_config['client_id'], $wpvs_vimeo_config['client_secret'], $wpvs_vimeo_api_key);
        $more_videos = false;
        if(isset($_REQUEST['vimeopage']) && $_REQUEST['vimeopage'] != "") {
            $new_videos_per_page = intval($_REQUEST['videosperpage']);
            if( $new_videos_per_page > 100 ) {
                $new_videos_per_page = 100;
            }
            if( $new_videos_per_page < 1 ) {
                $new_videos_per_page = 1;
            }
            update_option('wp-videos-admin-per-page', $new_videos_per_page);

            $get_page = $_REQUEST['vimeopage'];
            $get_vimeo_page = '/me/videos?page='.$get_page.'&per_page='.$new_videos_per_page.'&fields=name,uri,description,pictures';
            $response = $lib->request($get_vimeo_page, null, 'GET');
            $video_count = $response['body']['total'];
            $video_pages = ceil(intval($video_count)/$new_videos_per_page);
            $video_list = $response['body']['data'];

            if(intval($response['body']['page']) <= $video_pages) {
                $more_videos = true;
            }

            echo json_encode(array('more_videos' => $more_videos, 'video_pages' => $video_pages, 'videos' => $video_list));


        } else {
            status_header(400);
            echo "Invalid Vimeo page request.";
        }
    } else {
        status_header(400);
        echo "You have not entered your API Key, or it is invalid.";
    }
    wp_die();
}

add_action( 'wp_ajax_rvs_video_post_save_meta_ajax_request', 'rvs_video_post_save_meta_ajax_request' );

function rvs_video_post_save_meta_ajax_request() {
    if ( isset($_REQUEST) ) {
        $vimeoOptions = get_option('rvs_vimeo_video_settings');
        $videoSettings = $vimeoOptions['url'];
        $postId = $_REQUEST['postId'];
        $postTitle = get_the_title( $postId );
        $video_id = $_REQUEST['videoid'];
        $newiFrameSrc = 'https://player.vimeo.com/video/' . $video_id . $videoSettings;
        $newiFrame = '<iframe class="wpvs-vimeo-video-player" src="' . $newiFrameSrc . '" width="1280" height="720" frameborder="0" title="' . $postTitle . '" webkitallowfullscreen="" mozallowfullscreen="" allowfullscreen="" allow="autoplay"></iframe>';
        update_post_meta($postId, 'rvs_video_post_vimeo_html', $newiFrame);
        update_post_meta($postId, 'rvs_video_post_vimeo_id', $video_id);
        echo $newiFrame;
    }
    wp_die();
}

add_action( 'wp_ajax_wpv_import_vimeo_videos', 'wpv_import_vimeo_videos' );

function wpv_import_vimeo_videos() {
    global $wpvs_vimeo_api_key;
    if( ! empty($wpvs_vimeo_api_key) && get_option('rvs_key_authenticated')) {
        global $wpvs_vimeo_config;
        if(isset($_REQUEST['vimeopage']) && ! empty($_REQUEST['vimeopage']) ) {
            $lib = new Vimeo($wpvs_vimeo_config['client_id'], $wpvs_vimeo_config['client_secret'], $wpvs_vimeo_api_key);
            $new_videos_added = 0;
            $new_videos_per_page = intval($_REQUEST['videosperpage']);
            $checked_videos = $_REQUEST['videoarray'];
            $get_page = $_REQUEST['vimeopage'];
            $get_vimeo_page = '/me/videos?page='.$get_page.'&per_page='.$new_videos_per_page.'&fields=name,uri,description,pictures,duration';
            $response = $lib->request($get_vimeo_page, null, 'GET');
            $video_count = $response['body']['total'];
            $video_pages = ceil(intval($video_count)/$new_videos_per_page);
            $video_list = $response['body']['data'];
            $count_vimeo_videos = intval(wpvs_count_total_videos());
            $video_order = $count_vimeo_videos + 1;
            foreach($video_list as $video) {
                $vimeo_thumbnail_images = $video['pictures']['sizes'];
                $wpvs_video_images = wpvs_gather_vimeo_thumbnails($vimeo_thumbnail_images);
                $video_duration = $video['duration'];
                $video_uri = explode("videos/", $video['uri']);
                $video_id = $video_uri[1];
                if(in_array($video_id, $checked_videos)) {
                    $video_added = wpvideos_create_vimeo_video_post($video_id, $video['name'], $video['description'], $wpvs_video_images, $video_order, $video_duration);
                    $video_order++;
                    if($video_added) {
                        $new_videos_added++;
                    }
                }
            }
            echo $new_videos_added;

        } else {
            status_header(400);
            echo "Invalid Vimeo page request.";
        }
    } else {
        status_header(400);
        echo "You have not entered your API Key, or it is invalid.";
    }
    wp_die();
}

add_action( 'wp_ajax_wpvs_create_video_html_request', 'wpvs_create_video_html_request' );

function wpvs_create_video_html_request() {
    if ( isset($_POST['videosrc']) && ! empty($_POST['videosrc']) && isset($_POST['videowidth']) && ! empty($_POST['videowidth']) && isset($_POST['videoheight']) && ! empty($_POST['videoheight']) && isset($_POST['videotype']) && ! empty($_POST['videotype'])) {
        $video_src = $_POST['videosrc'];
        $video_width = $_POST['videowidth'];
        $video_height = $_POST['videoheight'];
        $video_type = $_POST['videotype'];
        $video_shortcode = '[video width="'.$video_width.'" height="'.$video_height.'" '.$video_type.'="'.$video_src.'"][/video]';
        echo do_shortcode( $video_shortcode );
    }
    wp_die();
}
