<?php

function wp_videos_add_css_scripts () {
    global $wpv_vimeosync_current_version;
    wp_enqueue_style( 'wp-videos-responsive', RVS_BASE_URL . 'css/responsive-video.css','', $wpv_vimeosync_current_version);
}
add_action( 'wp_enqueue_scripts', 'wp_videos_add_css_scripts' );

if( ! function_exists('vimeosync_plugin_add_video_to_content') ) {
    function vimeosync_plugin_add_video_to_content($post) {
        global $wpvs_genre_slug_settings;
        global $wpvs_actor_slug_settings;
        global $wpvs_director_slug_settings;
        $wpvs_autoplay = get_option('rvs_video_autoplay', 0);
        $rvs_video_type = get_post_meta($post->ID, '_rvs_video_type', true);
        if(empty($rvs_video_type)) {
            $rvs_video_type = "vimeo";
        }
        $tags = get_the_terms($post->ID, 'rvs_video_tags');
        $genres = get_the_terms($post->ID, 'rvs_video_category');

        $actor_term_args = array(
            'order' => 'ASC',
        );
        if( isset($wpvs_actor_slug_settings['ordering']) && $wpvs_actor_slug_settings['ordering'] == 'order' ) {
            $actor_term_args['meta_key'] = 'wpvs_display_order';
            $actor_term_args['orderby']  =  'meta_value_num';
        }
        $actors = wp_get_post_terms($post->ID, 'rvs_actors', $actor_term_args);

        $director_term_args = array(
            'order' => 'ASC',
        );
        if( isset($wpvs_director_slug_settings['ordering']) && $wpvs_director_slug_settings['ordering'] == 'order' ) {
            $director_term_args['meta_key'] = 'wpvs_display_order';
            $director_term_args['orderby']  =  'meta_value_num';
        }
        $directors = wp_get_post_terms($post->ID, 'rvs_directors', $director_term_args);

        $wpvs_video_information = get_post_meta($post->ID, 'wpvs_video_information', true);
        $video_download_link = null;
        $members_can_download = null;
        if( wpvs_check_for_membership_add_on() ) {
            $video_download_link = get_post_meta( $post->ID, 'rvs_video_download_link', true );
            $members_can_download = get_post_meta( $post->ID, 'wpvs_members_can_download', true );
            $download_link_text = get_post_meta( $post->ID, 'wpvs_download_link_text', true );
            if( empty($download_link_text) ) {
                $download_link_text = __('Download', 'vimeosync');
            }
        }

        $video_content = '<div class="rvs-responsive-video">';

        if( $rvs_video_type == "wordpress") {
            $rvs_wordpress_code = get_post_meta($post->ID, 'rvs_video_wordpress_code', true);
        }
        if( $rvs_video_type == "shortcode") {
            $rvs_shortcode_video = get_post_meta($post->ID, 'rvs_shortcode_video', true);
            $rvs_shortcode_video_check = get_post_meta($post->ID, 'rvs_shortcode_video_check', true);
        }

        if( $rvs_video_type == "wordpress" && ! empty($rvs_wordpress_code) ) {
            $video_content .= do_shortcode($rvs_wordpress_code);
        }
        if($rvs_video_type == "shortcode" && ! empty($rvs_shortcode_video) ) {
            if(! empty($rvs_shortcode_video_check) && shortcode_exists($rvs_shortcode_video_check)) {
                $video_content .= do_shortcode($rvs_shortcode_video);
            } else {
                $video_content .= __('Something is wrong with this videos Shortcode', 'vimeosync');
            }
        }
        if($rvs_video_type == "vimeo" || $rvs_video_type == "youtube") {
            $rvs_video_html = get_post_meta($post->ID, 'rvs_video_post_vimeo_html', true);
            $video_content .= $rvs_video_html;
        }

        if($rvs_video_type == "custom") {
            $video_content .= get_post_meta($post->ID, 'rvs_video_custom_code', true);
        }

        if( $wpvs_autoplay ) {
            $wpvs_autoplay_timer = get_option('wpvs_autoplay_timer', 5);
            $seconds_label = sprintf(__('starts in <span id="wpvs-autoplay-count">%d</span> seconds', 'vimeosync'), $wpvs_autoplay_timer);
            $video_content .= '<div id="wpvs-autoplay-countdown"><label id="wpvs-cancel-next-video"><span class="dashicons dashicons-no-alt"></span></label><a href="" id="wpvs-next-video-title"></a>'.$seconds_label.'</div>';
        }
        $video_content .= '</div>';

        if( ! empty($wpvs_video_information) ) {
            if( ( isset($wpvs_video_information['hours']) && ! empty($wpvs_video_information['hours']) ) || ( isset($wpvs_video_information['minutes']) && ! empty($wpvs_video_information['minutes']) ) ) {
                $video_content .= '<div id="wpvs-length-info-section" class="rvs-info-section"><span class="dashicons dashicons-clock"></span>';
                if( isset($wpvs_video_information['hours']) && ! empty($wpvs_video_information['hours']) ) {
                    $video_content .= $wpvs_video_information['hours'].'h ';

                }
                if( isset($wpvs_video_information['minutes']) && ! empty($wpvs_video_information['minutes']) ) {
                    $video_content .= $wpvs_video_information['minutes'].'m';
                }
                $video_content .= '</div>';
            }

            if( isset($wpvs_video_information['date_released']) && ! empty($wpvs_video_information['date_released']) ) {
                $video_content .= '<div id="wpvs-date-info-section" class="rvs-info-section"><span class="dashicons dashicons-calendar-alt"></span>'.$wpvs_video_information['date_released'].'</div>';
            }
        }

        if(!empty($actors)) {
            $video_content .= '<div id="wpvs-actor-info-section" class="rvs-info-section"><span class="dashicons dashicons-'.$wpvs_actor_slug_settings['icon'].'"></span>'.$wpvs_actor_slug_settings['name-plural'].': ';
            foreach($actors as $actor) {
                $video_content .= '<a href="'.get_site_url().'/'.$wpvs_actor_slug_settings['slug'].'/'.$actor->slug.'">'.$actor->name.'</a>';

                if ($actor != end($actors)) {
                    $video_content .= ', ';
                }
            }
            $video_content .= '</div>';
        }

        if(!empty($directors)) {
            $video_content .= '<div id="wpvs-director-info-section" class="rvs-info-section"><span class="dashicons dashicons-'.$wpvs_director_slug_settings['icon'].'"></span>'.$wpvs_director_slug_settings['name-plural'].': ';
            foreach($directors as $director) {
                $video_content .= '<a href="'.get_site_url().'/'.$wpvs_director_slug_settings['slug'].'/'.$director->slug.'">'.$director->name.'</a>';

                if ($director != end($directors)) {
                    $video_content .= ', ';
                }
            }
            $video_content .= '</div>';
        }

        if(!empty($genres)) {
            $video_content .= '<div id="wpvs-genre-info-section" class="rvs-info-section"><span class="dashicons dashicons-'.$wpvs_genre_slug_settings['icon'].'"></span>'.$wpvs_genre_slug_settings['name-plural'].': ';
            foreach($genres as $genre) {
                $video_content .= '<a href="'.get_site_url().'/'.$wpvs_genre_slug_settings['slug'].'/'.$genre->slug.'">'.$genre->name.'</a>';

                if ($genre != end($genres)) {
                    $video_content .= ', ';
                }
            }
            $video_content .= '</div>';
        }


        if(!empty($tags)) {
            $video_content .= '<div id="wpvs-tag-info-section" class="rvs-info-section"><span class="dashicons dashicons-tag"></span>';
            foreach($tags as $tag) {
                $video_content .= '<a href="'.get_site_url().'/video-tag/'.$tag->slug.'">'.$tag->name.'</a>';

                if ($tag != end($tags)) {
                    $video_content .= ', ';
                }
            }
            $video_content .= '</div>';
        }

        if( $members_can_download && ! empty($video_download_link) ) {
            $video_content .= '<div id="wpvs-download-info-section" class="rvs-info-section"><span class="dashicons dashicons-download"></span>';
            $video_content .= '<a href="'.$video_download_link.'" download>'.$download_link_text.'</a>';
            $video_content .= '</div>';
        }

        return $video_content;
    }
}

function rvs_filter_the_content( $content ) {
    global $post;
    $custom_content = "";
    if(get_option('rvs_video_position') == "below") {
        $custom_content = $content;
    }

    $custom_content .= vimeosync_plugin_add_video_to_content($post);

    if(get_option('rvs_video_position') == "above") {
        $custom_content .= $content;
    }
    return $custom_content;
}

if(!function_exists('wpvs_find_theme_override_template')) {
function wpvs_find_theme_override_template() {
    $wpvs_video_template_overide = 'wp-videos/rvs-video-template.php';
    $video_template = locate_template(
		array(
			 $wpvs_video_template_overide,
            true,
            false
		)
	);
    if( empty($video_template) ) {
        $video_template = RVS_BASE_DIR . '/template/rvs-video-template.php';
    }
    return $video_template;
}
}

function rvs_video_post_type_template($single_template) {
     global $post;
     if ($post->post_type == 'rvs_video') {
        wp_enqueue_style( 'dashicons' );
        add_filter( 'the_content', 'rvs_filter_the_content' );
     }
    return $single_template;
}
if( ! $wpvs_theme_is_active ) {
    if( ! wpvs_check_for_membership_add_on()) {
        add_filter( 'single_template', 'rvs_video_post_type_template' );
    }
}

function get_rvs_video_archive_template( $archive_template ) {
    global $wpvs_theme_is_active;
    if ( is_post_type_archive( 'rvs_video' ) && (! $wpvs_theme_is_active ) ) {
        global $wpv_vimeosync_current_version;
        global $rvs_load_template_css;
        if($rvs_load_template_css) {
            wp_enqueue_style('rvs-archive-styling', RVS_BASE_URL . 'css/rvs-archive.css','', $wpv_vimeosync_current_version);
        }
        $archive_template = wpvs_find_theme_override_template();
     }
     return $archive_template;
}
add_filter( 'archive_template', 'get_rvs_video_archive_template' ) ;

function get_rvs_video_taxonomy_template( $taxonomy_template ) {
    if( ! $wpvs_theme_is_active ) {
        if ( is_rvs_taxonomy() ) {
            global $wpv_vimeosync_current_version;
            global $rvs_load_template_css;
            if($rvs_load_template_css) {
                wp_enqueue_style('rvs-archive-styling', RVS_BASE_URL . 'css/rvs-archive.css','', $wpv_vimeosync_current_version);
            }
            $archive_template = wpvs_find_theme_override_template();
            $taxonomy_template = wpvs_find_theme_override_template();
        }
        return $taxonomy_template;
    }
}
if( ! $wpvs_theme_is_active ) {
add_filter( 'taxonomy_template', 'get_rvs_video_taxonomy_template' ) ;
}

if(!function_exists('is_rvs_taxonomy')) {
function is_rvs_taxonomy() {
    $is_rvs_tax = false;
    if(is_post_type_archive('rvs_video') || is_tax('rvs_video_category') || is_tax('rvs_video_tags') || is_tax('rvs_actors') || is_tax('rvs_directors')) {
        $is_rvs_tax = true;
    }
    return $is_rvs_tax;
}
}

if(!function_exists('rvs_get_video_thumbnail')) {
function rvs_get_video_thumbnail($video_id) {
    $thumbnail_image = get_post_meta($video_id, 'rvs_thumbnail_image', true);
    if( empty($thumbnail_image) ) {
        $rvs_thumbnails = get_post_meta($video_id, '_rvs_video_thumbnails', true);
        if(isset($rvs_thumbnails[3])) {
            $thumbnail_image = $rvs_thumbnails[3];
        }
        if( empty($thumbnail_image) && isset($rvs_thumbnails[2]) ) {
            $thumbnail_image = $rvs_thumbnails[2];
        }
        if(empty($thumbnail_image)) {
            $thumbnail_image = RVS_BASE_URL . 'image/missing-image.png';
        }
    }
    return $thumbnail_image;
}
}
